##  Description
Modeling the initiative fact sheet (and subtypes) allows you to see the status of initiatives and their impact on the entire landscape/enterprise architecture. More precisely, it shows an initiative’s impact on business capabilities, business contexts, applications, organizations, platforms, and IT components, as well as how it supports certain objectives. It also helps you surface relevant information, such as budget.
Overview of all relations to/from initiative:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio1b3e874ae68849f9b61d1fc151a0337b_LowRes.png)
